export async function up(entrances, ...args) {
    const [{ includes, excludes }] = Array.isArray(args[0])
        ? [{ includes: args[0], excludes: [] }]
        : [args[0]];
    const includeMatchers = includes.map(include => buildMatcher(include));
    const excludeMatchers = excludes.map(exclude => buildMatcher(exclude));
    const entryPromises = [];
    for (const key in entrances) {
        if (!includeMatchers.some(matcher => matcher(key)) ||
            excludeMatchers.some(matcher => matcher(key))) {
            continue;
        }
        entryPromises.push(Promise.resolve(entrances[key]).then(value => [key, value]));
    }
    return Object.fromEntries(await Promise.all(entryPromises));
}
function buildMatcher(pattern) {
    const starIndex = pattern.indexOf('*');
    if (starIndex < 0) {
        return key => key === pattern;
    }
    else {
        const prefix = pattern.slice(0, starIndex);
        const postfix = pattern.slice(starIndex + 1);
        return key => key.startsWith(prefix) && key.endsWith(postfix);
    }
}
//# sourceMappingURL=utils.js.map